==> lld-20.1.8-1.gpkg.tar: image/usr/lib/llvm/20/lib64/cmake/lld/LLDTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "lldCommon" for configuration "RelWithDebInfo"
set_property(TARGET lldCommon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldCommon PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldCommon.so.20.1+libcxx"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldCommon.so.20.1+libcxx"
  )

list(APPEND _cmake_import_check_targets lldCommon )
list(APPEND _cmake_import_check_files_for_lldCommon "${_IMPORT_PREFIX}/lib64/liblldCommon.so.20.1+libcxx" )

# Import target "lld" for configuration "RelWithDebInfo"
set_property(TARGET lld APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lld PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lld"
  )

list(APPEND _cmake_import_check_targets lld )
list(APPEND _cmake_import_check_files_for_lld "${_IMPORT_PREFIX}/bin/lld" )

# Import target "lldCOFF" for configuration "RelWithDebInfo"
set_property(TARGET lldCOFF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldCOFF PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "lldCommon;LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldCOFF.so.20.1+libcxx"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldCOFF.so.20.1+libcxx"
  )

list(APPEND _cmake_import_check_targets lldCOFF )
list(APPEND _cmake_import_check_files_for_lldCOFF "${_IMPORT_PREFIX}/lib64/liblldCOFF.so.20.1+libcxx" )

# Import target "lldELF" for configuration "RelWithDebInfo"
set_property(TARGET lldELF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldELF PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "lldCommon;zstd::libzstd_shared;LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldELF.so.20.1+libcxx"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldELF.so.20.1+libcxx"
  )

list(APPEND _cmake_import_check_targets lldELF )
list(APPEND _cmake_import_check_files_for_lldELF "${_IMPORT_PREFIX}/lib64/liblldELF.so.20.1+libcxx" )

# Import target "lldMachO" for configuration "RelWithDebInfo"
set_property(TARGET lldMachO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldMachO PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "lldCommon;LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldMachO.so.20.1+libcxx"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldMachO.so.20.1+libcxx"
  )

list(APPEND _cmake_import_check_targets lldMachO )
list(APPEND _cmake_import_check_files_for_lldMachO "${_IMPORT_PREFIX}/lib64/liblldMachO.so.20.1+libcxx" )

# Import target "lldMinGW" for configuration "RelWithDebInfo"
set_property(TARGET lldMinGW APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldMinGW PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "lldCOFF;lldCommon;LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldMinGW.so.20.1+libcxx"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldMinGW.so.20.1+libcxx"
  )

list(APPEND _cmake_import_check_targets lldMinGW )
list(APPEND _cmake_import_check_files_for_lldMinGW "${_IMPORT_PREFIX}/lib64/liblldMinGW.so.20.1+libcxx" )

# Import target "lldWasm" for configuration "RelWithDebInfo"
set_property(TARGET lldWasm APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldWasm PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "lldCommon;LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldWasm.so.20.1+libcxx"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldWasm.so.20.1+libcxx"
  )

list(APPEND _cmake_import_check_targets lldWasm )
list(APPEND _cmake_import_check_files_for_lldWasm "${_IMPORT_PREFIX}/lib64/liblldWasm.so.20.1+libcxx" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> lld-20.1.8-5.gpkg.tar: image/usr/lib/llvm/20/lib64/cmake/lld/LLDTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "lldCommon" for configuration "RelWithDebInfo"
set_property(TARGET lldCommon APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldCommon PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldCommon.so.20.1"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldCommon.so.20.1"
  )

list(APPEND _cmake_import_check_targets lldCommon )
list(APPEND _cmake_import_check_files_for_lldCommon "${_IMPORT_PREFIX}/lib64/liblldCommon.so.20.1" )

# Import target "lld" for configuration "RelWithDebInfo"
set_property(TARGET lld APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lld PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lld"
  )

list(APPEND _cmake_import_check_targets lld )
list(APPEND _cmake_import_check_files_for_lld "${_IMPORT_PREFIX}/bin/lld" )

# Import target "lldCOFF" for configuration "RelWithDebInfo"
set_property(TARGET lldCOFF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldCOFF PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "lldCommon;LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldCOFF.so.20.1"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldCOFF.so.20.1"
  )

list(APPEND _cmake_import_check_targets lldCOFF )
list(APPEND _cmake_import_check_files_for_lldCOFF "${_IMPORT_PREFIX}/lib64/liblldCOFF.so.20.1" )

# Import target "lldELF" for configuration "RelWithDebInfo"
set_property(TARGET lldELF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldELF PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "lldCommon;zstd::libzstd_shared;LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldELF.so.20.1"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldELF.so.20.1"
  )

list(APPEND _cmake_import_check_targets lldELF )
list(APPEND _cmake_import_check_files_for_lldELF "${_IMPORT_PREFIX}/lib64/liblldELF.so.20.1" )

# Import target "lldMachO" for configuration "RelWithDebInfo"
set_property(TARGET lldMachO APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldMachO PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "lldCommon;LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldMachO.so.20.1"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldMachO.so.20.1"
  )

list(APPEND _cmake_import_check_targets lldMachO )
list(APPEND _cmake_import_check_files_for_lldMachO "${_IMPORT_PREFIX}/lib64/liblldMachO.so.20.1" )

# Import target "lldMinGW" for configuration "RelWithDebInfo"
set_property(TARGET lldMinGW APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldMinGW PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "lldCOFF;lldCommon;LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldMinGW.so.20.1"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldMinGW.so.20.1"
  )

list(APPEND _cmake_import_check_targets lldMinGW )
list(APPEND _cmake_import_check_files_for_lldMinGW "${_IMPORT_PREFIX}/lib64/liblldMinGW.so.20.1" )

# Import target "lldWasm" for configuration "RelWithDebInfo"
set_property(TARGET lldWasm APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(lldWasm PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "lldCommon;LLVM"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/liblldWasm.so.20.1"
  IMPORTED_SONAME_RELWITHDEBINFO "liblldWasm.so.20.1"
  )

list(APPEND _cmake_import_check_targets lldWasm )
list(APPEND _cmake_import_check_files_for_lldWasm "${_IMPORT_PREFIX}/lib64/liblldWasm.so.20.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
